@@ -2,7 +2,7 @@ import logging
 logger = logging.getLogger("classy_mail")
 from mixins.filesystem import FileTemplateMixin
 from mixins.model import ModelTemplateMixin
-from mixins.log import LogMessageMixin
+from mixins.log import LogMessageMixin, UniqueMessageMixin
 from mixins.md_template import MarkdownTemplateMixin
 from .base import BaseEmail
 
@@ -17,3 +17,6 @@ class FileTemplateEmail(LogMessageMixin, FileTemplateMixin, BaseEmail):
 
 class MarkdownTemplateEmail(LogMessageMixin, MarkdownTemplateMixin, BaseEmail):
     pass
+
+class UniqueMarkdownTemplateEmail(UniqueMessageMixin, MarkdownTemplateMixin, BaseEmail):
+    pass
